var NAVTREEINDEX0 =
{
"Periodic_4_hyperbolic_triangulation_2_2p4ht2_example_insertion_8cpp-example.html":[4,0],
"annotated.html":[3],
"citelist.html":[2],
"classCGAL_1_1Hyperbolic__octagon__translation.html":[1,0,4,0],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a0c6490e307f41e375712a6d7895e61eb":[1,0,4,0,17],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a1a1bf02b0394d062d0cf61eec6c0c5e4":[1,0,4,0,20],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a1b828bcb39acaea8e900e725ca0a08cb":[1,0,4,0,21],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a1bfeda2bb18a284c4681355af26400d3":[1,0,4,0,8],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a21e7e39b1e8d05d3ab29f062d93b5522":[1,0,4,0,16],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a254a43e84f561bc1b879e3bb36e73680":[1,0,4,0,0],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a2d57b183a389a33b7ea060fc75896248":[1,0,4,0,9],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a442de2077cff54c0609cb5f7a70decc7":[1,0,4,0,13],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a4ea953225f0e6c87554ca1090016785c":[1,0,4,0,4],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a50982f5e7032905da33a9ac68e9f552c":[1,0,4,0,10],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a530110568fd0a764041421c93275194c":[1,0,4,0,22],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a5b9e99efa74ee9276c20d9b92587c0a9":[1,0,4,0,2],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a5bb2708ed54de82fbba0ada80709191f":[1,0,4,0,1],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a6b22f0840e88bcc29a9753d5167faf66":[1,0,4,0,18],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a944ed983ee89dda20df73ac04d5bac21":[1,0,4,0,15],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a97cebd3c2126c19fa1d145ab88d98691":[1,0,4,0,5],
"classCGAL_1_1Hyperbolic__octagon__translation.html#a9d6af8f98be2af857543ba893d655fcb":[1,0,4,0,19],
"classCGAL_1_1Hyperbolic__octagon__translation.html#aaf97d55846cac76b7b1cf54f174efea8":[1,0,4,0,12],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ac433d08b2cabbd8430e46fc1ffec8072":[1,0,4,0,14],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ac94a8373cefcf9049b98a78f0a09e198":[1,0,4,0,11],
"classCGAL_1_1Hyperbolic__octagon__translation.html#aca30c88c634de89324195f961b46def3":[1,0,4,0,6],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ad8d7068cd336de2c5a59b841b6d32b3d":[1,0,4,0,3],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ad8d7068cd336de2c5a59b841b6d32b3da4ead79d6ef637af4c126ec9a2440fecc":[1,0,4,0,3,0],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ad8d7068cd336de2c5a59b841b6d32b3da5730682d74b1f8e157816b76e86fdb4b":[1,0,4,0,3,7],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ad8d7068cd336de2c5a59b841b6d32b3da701b8165b5a1e3d80edb73c710bb5560":[1,0,4,0,3,1],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ad8d7068cd336de2c5a59b841b6d32b3da7094843f065ec4e065aae01695efc83d":[1,0,4,0,3,4],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ad8d7068cd336de2c5a59b841b6d32b3da8aea3697456cb0be249905c3d5d948a0":[1,0,4,0,3,5],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ad8d7068cd336de2c5a59b841b6d32b3da8bc2157cf8ac46166bd9b561858da329":[1,0,4,0,3,6],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ad8d7068cd336de2c5a59b841b6d32b3da9fe586db8dd96718764d573152efb220":[1,0,4,0,3,2],
"classCGAL_1_1Hyperbolic__octagon__translation.html#ad8d7068cd336de2c5a59b841b6d32b3dadbc22366196c800cc9ecd42b910e6e77":[1,0,4,0,3,3],
"classCGAL_1_1Hyperbolic__octagon__translation.html#aff5e92ec8b2419811dc5907ed407a5c3":[1,0,4,0,7],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html":[1,0,1,0],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#a13dd5c6bb176b592f565c94dd715b2ff":[1,0,1,0,13],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#a270b7d899609698a96173fa57de9c9ae":[1,0,1,0,5],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#a4524c33a3fda149aa65f702b02d763ad":[1,0,1,0,12],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#a6ab429f8e5470cffce77610b16e690a4":[1,0,1,0,7],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#a7f598f8ae79fb95428f8fd35b489a48c":[1,0,1,0,9],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#a80bf3949107c8287326a35a1d0a2a43a":[1,0,1,0,2],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#a9af599aac9d65a701c9bdecbd2228d71":[1,0,1,0,0],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#aa5c1b2295bab6aed12a8a82b251b0c37":[1,0,1,0,1],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#aaa7ff8045af0ec754a7d5d1b80870549":[1,0,1,0,14],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#abe1244616e8b12326d63f715a846fb18":[1,0,1,0,8],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#ac310c352e4544dff97a948ff5f2e36b5":[1,0,1,0,6],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#ae7c12c91f13ea54df126e9c22b02c9dc":[1,0,1,0,3],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#ae85445e20fd5a5f85fb80ac3581cd3ec":[1,0,1,0,11],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#af798753827b44258c1086d3752e93642":[1,0,1,0,10],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__2.html#afe630134b25dd6c11dce6fa38ca84ffd":[1,0,1,0,4],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__traits__2.html":[1,0,2,0],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__traits__2.html#a3896d5c20859e3e4bd96df9d06012db0":[1,0,2,0,3],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__traits__2.html#a55c4fcfe1efc8191c45c9b61f16c8f79":[1,0,2,0,5],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__traits__2.html#a6d04c232110f5d9af442c1e9a86e7c2d":[1,0,2,0,4],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__traits__2.html#a8b488b80ff4eccc29dc1492d57a34507":[1,0,2,0,2],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__traits__2.html#aa7ec5a0a66945d451952b0dea67d9750":[1,0,2,0,1],
"classCGAL_1_1Periodic__4__hyperbolic__Delaunay__triangulation__traits__2.html#af84a20bf7301e2b30b70159c8fcc94eb":[1,0,2,0,0],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html":[1,0,1,1],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a04f6434b49778a37d8045a95c405ce92":[1,0,1,1,77],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a0d321e2d6808275d0e157298adf369dc":[1,0,1,1,16],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a0dabc02f50453e5bb520fa1466696db1":[1,0,1,1,24],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a11112d1ac6a6bc2d8dffa116763b91fd":[1,0,1,1,59],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a13e31358d6d33a45ae31bc367b9a48d4":[1,0,1,1,70],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a1697a399af990b82dc68ac818ecb3360":[1,0,1,1,0],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a193f6ef9bb654117476cd605c921e638":[1,0,1,1,68],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a1c015753736e9882c227398ff7ad00e0":[1,0,1,1,44],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a1d9a6741108122a4fbcf3d83519f1f10":[1,0,1,1,33],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a230b688fadea0e62cf7718cf3892db99":[1,0,1,1,8],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a25c2082ad6e3f108637dac18f9aea248":[1,0,1,1,25],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a2627e00c6e79f909264ac10ebdcd197d":[1,0,1,1,61],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a27d9db3df92a7d68ce4bd762e70e3c81":[1,0,1,1,29],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a284693e1a0b10b44ecf4b96d08199a3c":[1,0,1,1,63],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a2c0fa229047ef84b5c7bf3ca902e1b03":[1,0,1,1,41],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a2e44c0207d54d2e819db330cd3501087":[1,0,1,1,21],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a30469c4b78fc61351c358d0c58ee779b":[1,0,1,1,55],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a30ea25e91e4eb1a8f77b4d40d73e6c2d":[1,0,1,1,56],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a33156c2c5fc591ebae02ab46eef01686":[1,0,1,1,58],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a33fe630bef9aa63590cc989b22019414":[1,0,1,1,48],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a3e5da8d9fad355771e7e1b5c016428be":[1,0,1,1,74],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a42bfde2e714960b9f203df99d68e9728":[1,0,1,1,34],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a436e182c64d5e98b0e7559eb7cdcb798":[1,0,1,1,19],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a436e182c64d5e98b0e7559eb7cdcb798acf07c710808ef267e1efb9ae46a582c4":[1,0,1,1,19,2],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a436e182c64d5e98b0e7559eb7cdcb798ae345997ec79d36a799893959a670b489":[1,0,1,1,19,0],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a436e182c64d5e98b0e7559eb7cdcb798af860c7a9ced09f4e972e53b6bea2f950":[1,0,1,1,19,1],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a46d0a8c4134508b879e81f927c587b61":[1,0,1,1,20],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a48a91c10a576975fccebec72f00b139e":[1,0,1,1,40],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a4900fe2e4ea7a1ddb0c16635bb824dfb":[1,0,1,1,11],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a4e525de6cdd384fde80a34418c03f2fb":[1,0,1,1,73],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a59f835c7ff55e762375604aa5b89ea69":[1,0,1,1,2],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a5bf7d89f6040739bb14f9e563749954c":[1,0,1,1,50],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a5ddaf1929123ca4f11ab7b33965bd7e4":[1,0,1,1,38],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a5f548267867af5a67b80df8bd7f73159":[1,0,1,1,31],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a650d6dc0b8c4616f678a0f4a0c3f00f2":[1,0,1,1,79],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a657734ed6430da84a35612f9817dedf7":[1,0,1,1,28],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a68a26190dabd6e0d54324b23babefc39":[1,0,1,1,13],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a71d9d9e3de9e1249febe25a9a0d3be8c":[1,0,1,1,3],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a73bcd19fad6fc8395b7a5a4f1065bbbf":[1,0,1,1,45],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a78d25ff16ba5e0503077588da7c7072b":[1,0,1,1,18],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a7a189c9dd2b481d3ca6b861434fbc243":[1,0,1,1,76],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a7a36c97f2cfc5e2a3e03d046ede3dc92":[1,0,1,1,26],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a7c99929bbfdac02cf8a7900288048e86":[1,0,1,1,39],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a7cb1725a5f11fd4ed53b0130efbfe007":[1,0,1,1,5],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a7d1c800014ef2b9d2f0f89e3e04a9917":[1,0,1,1,1],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a7fcc7a09aef396a6e02d6634d4e04652":[1,0,1,1,9],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a816539b95ac507044147175a9fcc2831":[1,0,1,1,46],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a83fb42962258c2c3359beb57b888505d":[1,0,1,1,23],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a848ec25c9871df5b76e74a90730988f1":[1,0,1,1,49],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a8544571f69f18c49ad0c3753d8f04e53":[1,0,1,1,65],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a858593bca922f372a145afd70cc60197":[1,0,1,1,62],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a85b1b2536bba81c2b3201bcc94858ef2":[1,0,1,1,75],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a8a2b1172c6a694550836439c092a92bd":[1,0,1,1,43],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a8b2f9895569cf16ab84093323b91f4de":[1,0,1,1,66],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a9680245b9423626ababd7cb634ab58de":[1,0,1,1,78],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a9996b21621ce235fbd5502d5856c8cc1":[1,0,1,1,22],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a9da1ad96ba5aa1c806b4df6abfc1c47e":[1,0,1,1,64],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#a9eae1a62072eae78f4b0a811ffa39e9b":[1,0,1,1,72],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#aadb7cc82882417c0df7f6adda0cc11d6":[1,0,1,1,27],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#aaede65c7cc764c63ca66b436ba9c517c":[1,0,1,1,30],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ab2fd5eeb3ee19c3cee8f7a7ea6258eb9":[1,0,1,1,47],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ab4df46614d71658cbec38546659bed07":[1,0,1,1,57],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ab525a17b16400c774bf00946957b235a":[1,0,1,1,7],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ab872bbe67066e4ea6a46d71e08a4a6ab":[1,0,1,1,69],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#aba1adfa7d4db7261d38d4972616588b6":[1,0,1,1,60],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#abc1d10819881baacdbb8bb3796244347":[1,0,1,1,54],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ac54fae739b2fa2231e922e9e37cdb08d":[1,0,1,1,6],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ac555dd822ee65a95ba9e8e85417c1d2a":[1,0,1,1,53],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ac67c69ca6beacc42e87f06517412d5ea":[1,0,1,1,71],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ac78bc4a187fde1ef9978e863fcc8f3ec":[1,0,1,1,37],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ac84ceec1826d2310ded9046ad50c9461":[1,0,1,1,52],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#acd0774193284912aa4aa5b7665dcf9cf":[1,0,1,1,12],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ad41e2e641144563cdd42d4c9b8ef730f":[1,0,1,1,36],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ad51f9bc20b86c985f89dcf0d7623f233":[1,0,1,1,42],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ad8dd8dbc69e7924f1dbf34f85ac707d4":[1,0,1,1,14],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#adc6bb191b91515bb3ed0067e88d76939":[1,0,1,1,67],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ae37a45a43a0779b701935108f09fe2b0":[1,0,1,1,17],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ae3fab38a805868b5ade4b6fb88c8c7d6":[1,0,1,1,15],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ae6efd748aa057621e924cd8e2da2de90":[1,0,1,1,10],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ae8c3dd43711c45ce859ac0b8cc165ab0":[1,0,1,1,4],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#ae94653f306ef2cb796b39b1bfae14703":[1,0,1,1,35],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#aea2576ccaf7606f2b41adc0fe18d5e1f":[1,0,1,1,32],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__2.html#affbd9dbbb859b500cf4e43ceb21da3fc":[1,0,1,1,51],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__face__base__2.html":[1,0,3,0],
"classCGAL_1_1Periodic__4__hyperbolic__triangulation__vertex__base__2.html":[1,0,3,1],
"classPeriodic__4HyperbolicDelaunayTriangulationTraits__2.html":[1,0,0,0],
"classPeriodic__4HyperbolicDelaunayTriangulationTraits__2.html#a5eaeae3225aac22b0fbbf300be1b2a78":[1,0,0,0,0],
"classPeriodic__4HyperbolicDelaunayTriangulationTraits__2.html#a8e6bd081ec6afc187bd47ae8c11bbee5":[1,0,0,0,1],
"classPeriodic__4HyperbolicTriangulationFaceBase__2.html":[1,0,0,1],
"classPeriodic__4HyperbolicTriangulationFaceBase__2.html#a1406a41ea4e925cf0eb73232ef29e961":[1,0,0,1,3],
"classPeriodic__4HyperbolicTriangulationFaceBase__2.html#a2685c16bd605ad0474eef0fccff0b2f4":[1,0,0,1,0],
"classPeriodic__4HyperbolicTriangulationFaceBase__2.html#a2ecf18c207d7f6f3605f2b1a599d7484":[1,0,0,1,6],
"classPeriodic__4HyperbolicTriangulationFaceBase__2.html#a5b6760e84fd902965434e255963d5e1c":[1,0,0,1,4],
"classPeriodic__4HyperbolicTriangulationFaceBase__2.html#a8515c535c2968282628964395e127f65":[1,0,0,1,5],
"classPeriodic__4HyperbolicTriangulationFaceBase__2.html#ade0ef51744f62950141989dc72093444":[1,0,0,1,1],
"classPeriodic__4HyperbolicTriangulationFaceBase__2.html#adf7cfc8af58a6120572e0ad2c150ae4d":[1,0,0,1,7],
"classPeriodic__4HyperbolicTriangulationFaceBase__2.html#afb53cda22107cc8f3b5680a1625e0b48":[1,0,0,1,2],
"classPeriodic__4HyperbolicTriangulationTraits__2.html":[1,0,0,2],
"classPeriodic__4HyperbolicTriangulationTraits__2.html#a11204b8e150c2ba687d6b7597abd55bc":[1,0,0,2,4],
"classPeriodic__4HyperbolicTriangulationTraits__2.html#a7bea9b3ce40c91e8be4cfb18528d9b52":[1,0,0,2,1],
"classPeriodic__4HyperbolicTriangulationTraits__2.html#ab524a05902c9aa40b7266f5384fcaaaa":[1,0,0,2,3],
"classPeriodic__4HyperbolicTriangulationTraits__2.html#ae089c9e72f08125bfe1615fbefc26635":[1,0,0,2,0],
"classPeriodic__4HyperbolicTriangulationTraits__2.html#ae74163db9eaef8de0b45c6a1702f4dd9":[1,0,0,2,2],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html":[1,0,0,3],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#a043e851c8e523a4dc8132fc646d59a35":[1,0,0,3,4],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#a6af874452af8a91a8bd37a8b02efdc19":[1,0,0,3,5],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#a7debbedeee95a80fa6faa67037157d32":[1,0,0,3,11],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#a8b83d3733b38e133e71b6779d616a4f6":[1,0,0,3,0],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#a9097c7a4a46b87c81f339545838dc454":[1,0,0,3,8],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#ab0f09f6ced9961f1646247dfa888524a":[1,0,0,3,1],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#ab900071e5e85381465d57af0b4c446ef":[1,0,0,3,6],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#ac87a73e55044fbd029417a855bc12c1b":[1,0,0,3,2],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#ace5b00efd46487ef95c20bf76b8ff20b":[1,0,0,3,7],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#adb210d77458f85871f5c2de56a87860a":[1,0,0,3,3],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#adb5edc44492839dce527f1b48066182e":[1,0,0,3,9],
"classPeriodic__4HyperbolicTriangulationVertexBase__2.html#ae64a960bbd763dc0ccd7fad4ca949b90":[1,0,0,3,10],
"examples.html":[4],
"group__PkgPeriodic4HyperbolicTriangulation2Concepts.html":[1,0,0],
"group__PkgPeriodic4HyperbolicTriangulation2HyperbolicTranslationsClasses.html":[1,0,4],
"group__PkgPeriodic4HyperbolicTriangulation2MainClasses.html":[1,0,1],
"group__PkgPeriodic4HyperbolicTriangulation2Ref.html":[1,0],
"group__PkgPeriodic4HyperbolicTriangulation2TraitsClasses.html":[1,0,2],
"group__PkgPeriodic4HyperbolicTriangulation2VertexFaceClasses.html":[1,0,3],
"index.html":[0],
"index.html":[],
"index.html#P4HT2_Data_structure":[0,1,0],
"index.html#P4HT2_Design":[0,5],
"index.html#P4HT2_Embedding_condition":[0,1,1],
"index.html#P4HT2_Performance":[0,4],
"index.html#P4HT2_datastructure":[0,2,1],
"index.html#P4HT2_design":[0,2],
"index.html#P4HT2_examples":[0,3],
"index.html#P4HT2_representation":[0,1],
"index.html#P4HT2_thespace":[0,0],
"index.html#P4HT2_traits":[0,2,0],
"modules.html":[1],
"pages.html":[]
};
